#
# spec file for package mvapich2
#
# Copyright (c) 2014-2017 Intel Corporation. All rights reserved.
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Strongly suggested rpmbuild defines (and example values):
#	--define "_name mvapich2_gcc_hfi"
#	--define "_prefix /usr/mpi/gcc/mvapich2-2.2-5-hfi"
#       --define "impl ofa"
#           OR
#       --define "impl psm"


# Optional rpmbuild defines (and example values):
#       --define "configargs --with-psm=no"
#	--define "comp_env CC=gcc CXX=g++ "
#	--define "channel ch3:psm"
#	--define "mpi_selector /usr/bin/mpi-selector"

%define debug_package %{nil}
%{!?_name: %global _name mvapich2}
%{!?auto_req: %global auto_req 1}

Name:           %{_name}
Summary:        OSU MVAPICH2 MPI package
License:        BSD-3-Clause
Group:          Development/Libraries/Parallel
Version:        2.3b
Release:        10
Source0:        mvapich2-%{version}-%{release}.tar.gz
Url:            http://mvapich.cse.ohio-state.edu/overview/mvapich2/
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if %{auto_req}
Autoreq: 1
%else
Autoreq: 0
%endif

BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  bison
BuildRequires:  mpi-selector
Requires:  mpi-selector

%if "%{impl}" == "ofa"
%if 0%{?rhel}
Requires:  libibverbs
Requires:  librdmacm
%else
Requires:  libibverbs1
Requires:  librdmacm1
%endif
BuildRequires:  libibverbs-devel
BuildRequires:  librdmacm-devel
%define withpsm --with-psm=no
%endif

%if "%{impl}" == "psm"
Requires:       infinipath-psm
BuildRequires:  infinipath-psm-devel
%define channel ch3:psm
%define withpsm --with-psm
%endif

%if "%{impl}" == "psm2"
Requires:       libpsm2
BuildRequires:  libpsm2-devel
%define channel ch3:psm
%define withpsm --with-psm2
%endif


%description
This is an MPI-3 implementation which includes all MPI-1 features. It
is based on MPICH2 and MVICH.


%prep
#Do not allow building without specifying --mpi_selector
%if %{?mpi_selector:0}%{!?mpi_selector:1}
    echo
    echo "ERROR: must specify --mpi_selector=<PATH>"
    echo
    exit 1
%endif

%setup -q -n mvapich2-%{version}-%{release}


%build
#%{?comp_env} ./autogen.sh

%{?comp_env} ./configure --prefix=%_prefix \
	--without-mpe --disable-mcast \
	%{?shared_libs: --enable-shared} \
	%{?channel: --with-device=%{channel}} \
	%{?withpsm} \
	%{?configargs} \
	--mandir=%{_prefix}/share/man \
	--libexecdir=%{_prefix}/libexec \
	--disable-maintainer-mode
%{?comp_env} make %{?_smp_mflags}


%install
%{?comp_env} make DESTDIR=%{buildroot} install
rm -f %{buildroot}%{_libdir}/libfmpich.la \
      %{buildroot}%{_libdir}/libmpich.la \
      %{buildroot}%{_libdir}/libmpichcxx.la \
      %{buildroot}%{_libdir}/libmpichf90.la \
      %{buildroot}%{_libdir}/libmpl.la \
      %{buildroot}%{_libdir}/libopa.la

mkdir -p %{buildroot}%{_datadir}/doc/mvapich2
%{?comp_env} install -m 0644 COPYRIGHT* %{buildroot}%{_datadir}/doc/mvapich2
%{?comp_env} install -m 0644 CHANGE* %{buildroot}%{_datadir}/doc/mvapich2

# Additionally, create the mpivars.[c]sh files.
cat > $RPM_BUILD_ROOT/%_prefix/bin/mpivars.csh <<EOF
if (\$?path) then
    if ( "\${path}" !~ *%{_prefix}/bin* ) then
        set path = ( %{_prefix}/bin \$path )
    endif
else
    set path = ( %{_prefix}/bin )
endif

if ("1" == "\$?LD_LIBRARY_PATH") then
    if ("\$LD_LIBRARY_PATH" !~ *%{_prefix}/lib) then
        setenv LD_LIBRARY_PATH %{_prefix}/lib:\${LD_LIBRARY_PATH}
    endif
else
    setenv LD_LIBRARY_PATH %{_prefix}/lib
endif

if (\$?MANPATH) then
    if ( "\${MANPATH}" !~ *%{_prefix}/man* ) then
        setenv MANPATH %{_prefix}/man:\$MANPATH
    endif
else
    setenv MANPATH %{_prefix}/man:
endif
EOF

cat > $RPM_BUILD_ROOT/%_prefix/bin/mpivars.sh <<EOF
if ! echo \${PATH} | grep -q %{_prefix}/bin ; then
    PATH=%{_prefix}/bin:\${PATH}
fi

if ! echo \${LD_LIBRARY_PATH} | grep -q %{_prefix}/lib ; then
    export LD_LIBRARY_PATH=%{_prefix}/lib:\${LD_LIBRARY_PATH}
fi

if ! echo \${MANPATH} | grep -q %{_prefix}/man ; then
    MANPATH=%{_prefix}/man:\${MANPATH}
fi
EOF


%clean
rm -rf %{buildroot}


%post
/sbin/ldconfig
%{mpi_selector} \
        --register %{name}-%{version} \
        --source-dir %{_bindir} \
        --yes

%preun
%{mpi_selector} --unregister %{name}-%{version} --yes || \
      /bin/true >/dev/null 2>/dev/null

%postun
/sbin/ldconfig


%files
%defattr(-, root, root)
%{_prefix}


%changelog
* Thu Apr 19 2018 <matias.a.cabral@intel.com>
- Add build support for SLES 15

* Fri Feb 2 2018 <matias.a.cabral@intel.com>
- Patch sent by MVPICH2 team to address hang in mixed KNL and XEON executions.

* Fri Jan 19 2018 <matias.a.cabral@intel.com>
- Patch sent by MVPICH2 team to address SHM issues with IMB-MPI1

* Tue Jan 2 2018 <matias.a.cabral@intel.com>
- Add mpi-selector as an RPM dependency

* Mon Oct 16 2017 <nikhil.potade@intel.com>
- INTERNAL: SL-3207: Execute MPI benchmarks using mvapich 2.3b verbs build

* Wed Aug 23 2017 <wojciech.wasko@intel.com>
- Building scripts applied to MVAPICH2-2.3a release

* Wed Aug 23 2017 <tymoteusz.kielan@intel.com>
- Fix debian installation files

* Wed Aug 23 2017 <tymoteusz.kielan@intel.com>
- Add Ubuntu support

* Wed Aug 23 2017 <tymoteusz.kielan@intel.com>
- Fix autogen issues

* Wed Aug 23 2017 <wojciech.wasko@intel.com>
- Use unsigned int for max message size for PSM2

